;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "justl" "20250909.422"
  "Major mode for driving just files."
  '((transient  "0.1.0")
    (emacs      "27.1")
    (s          "1.2.0")
    (f          "0.20.0")
    (inheritenv "0.2"))
  :url "https://github.com/psibi/justl.el"
  :commit "8096ebd602f374936be2c14cbc6b2e7768c3fccf"
  :revdesc "8096ebd602f3"
  :keywords '("just" "justfile" "tools" "processes"))
